@@ -683,62 +683,29 @@ Rose::HTML::Form - HTML form base class.
 
 =head1 DESCRIPTION
 
-L<Rose::HTML::Form> is more than just an object representation of the
-E<lt>formE<gt> HTML tag.  It is meant to be a base class for custom form
-classes that can be initialized with and return "rich" values such as objects,
-or collections of objects.
+L<Rose::HTML::Form> is more than just an object representation of the E<lt>formE<gt> HTML tag.  It is meant to be a base class for custom form classes that can be initialized with and return "rich" values such as objects, or collections of objects.
 
-Building up a reusable library of form classes is extremely helpful when
-building large web applications with forms that may appear in many different
-places.  Similar forms can inherit from a common subclass.
+Building up a reusable library of form classes is extremely helpful when building large web applications with forms that may appear in many different places.  Similar forms can inherit from a common subclass.
 
-This class inherits from, and follows the conventions of,
-L<Rose::HTML::Object>. Inherited methods that are not overridden will not be
-documented a second time here.  See the L<Rose::HTML::Object> documentation
-for more information.
+This class inherits from, and follows the conventions of, L<Rose::HTML::Object>. Inherited methods that are not overridden will not be documented a second time here.  See the L<Rose::HTML::Object> documentation for more information.
 
 =head1 OVERVIEW
 
-L<Rose::HTML::Form> objects are meant to encapsulate an entire HTML form,
-including all fields within the form. While individual fields may be queried
-and manipulated, the intended purpose of this class is to treat the form as a
-"black box" as much as possible.
+L<Rose::HTML::Form> objects are meant to encapsulate an entire HTML form, including all fields within the form. While individual fields may be queried and manipulated, the intended purpose of this class is to treat the form as a "black box" as much as possible.
 
-For example, instead of asking a form object for the values of the "name",
-"email", and "phone" fields, the user would ask the form object to return a
-new "Person" object that encapsulates those values.
+For example, instead of asking a form object for the values of the "name", "email", and "phone" fields, the user would ask the form object to return a new "Person" object that encapsulates those values.
 
-Form objects should also accept initialization through the same kinds of
-objects that they return.  Subclasses are encouraged to create methods such as
-(to use the example described above) C<init_with_person()> and
-C<person_from_form()> in order to do this.  The generic methods
-C<init_with_object()> and C<object_from_form()> are meant to ease the
-implementation of such custom methods.
+Form objects should also accept initialization through the same kinds of objects that they return.  Subclasses are encouraged to create methods such as (to use the example described above) C<init_with_person()> and C<person_from_form()> in order to do this.  The generic methods L<init_with_object()|/init_with_object> and L<object_from_form()|/object_from_form> are meant to ease the implementation of such custom methods.
 
-Form objects can also take input through a hash.  Each hash key correspond to
-a field (or subfield) name, and each value is either a scalar or a reference
-to an array of scalars (for multiple-value fields).  This hash of parameters
-can be queried and manipulated before finally calling C<init_fields()> in order
-to initialize the fields based on the current state of the parameters.
+Form objects can also take input through a hash.  Each hash key correspond to a field (or subfield) name, and each value is either a scalar or a reference to an array of scalars (for multiple-value fields).  This hash of parameters can be queried and manipulated before finally calling L<init_fields()|/init_fields> in order to initialize the fields based on the current state of the parameters.
 
-Compound fields (fields consisting of more than one HTML field, such as a
-month/day/year date field with separate text fields for each element of the
-date) may be "addressed" by hash arguments using both top-level names (e.g.,
-"birthday") or by subfield names (e.g., "birthday.month", "birthday.day",
-"birthday.year").  If the top-level name exists in the hash, then subfield
-names are ignored.
+Compound fields (fields consisting of more than one HTML field, such as a month/day/year date field with separate text fields for each element of the date) may be "addressed" by hash arguments using both top-level names (e.g., "birthday") or by subfield names (e.g., "birthday.month", "birthday.day", "birthday.year").  If the top-level name exists in the hash, then subfield names are ignored.
 
-(See L<Rose::HTML::Form::Field::Compound> for more information on compound
-fields.)
+(See L<Rose::HTML::Form::Field::Compound> for more information on compound fields.)
 
-Each form has a list of field objects.  Each field object is stored under a
-name, which may or may not be the same as the field name, which may or may not
-be the same as the "name" HTML attribute for any of the HTML tags that make up
-that field.
+Each form has a list of field objects.  Each field object is stored under a name, which may or may not be the same as the field name, which may or may not be the same as the "name" HTML attribute for any of the HTML tags that make up that field.
 
-Forms are validated by calling C<validate()> on each field object.  If any
-individual field does not validate, then the form is invalid. Inter-field
-validation is the responsibility of the form object.
+Forms are validated by calling L<validate()|Rose::HTML::Form::Field/validate> on each field object.  If any individual field does not validate, then the form is invalid. Inter-field validation is the responsibility of the form object.
 
 =head1 HTML ATTRIBUTES
 
@@ -787,8 +754,7 @@ Required attributes (default values in parentheses):
 
 =item B<new PARAMS>
 
-Constructs a new L<Rose::HTML::Form> object based on PARAMS, where PARAMS are
-name/value pairs.  Any object method is a valid parameter name.
+Constructs a new L<Rose::HTML::Form> object based on PARAMS, where PARAMS are name/value pairs.  Any object method is a valid parameter name.
 
 =back
 
@@ -798,25 +764,19 @@ name/value pairs.  Any object method is a valid parameter name.
 
 =item B<add_field ARGS>
 
-Convenience alias for C<add_fields()>.
+Convenience alias for L<add_fields()|/add_fields>.
 
 =item B<add_fields ARGS>
 
 Add the fields specified by ARGS to the list of fields contained in this form.
 
-If an argument is "isa" L<Rose::HTML::Form::Field>, then it is added to the
-list of fields, stored under the name returned by the field's C<name()> method.
+If an argument is "isa" L<Rose::HTML::Form::Field>, then it is added to the list of fields, stored under the name returned by the field's L<name()|Rose::HTML::Form::Field/name> method.
 
-If an argument is anything else, it is used as the field name, and the next
-argument is used as the field object to store under that name.  If the next
-argument is not an object derived from L<Rose::HTML::Form::Field>, then a
-fatal error occurs.
+If an argument is anything else, it is used as the field name, and the next argument is used as the field object to store under that name.  If the next argument is not an object derived from L<Rose::HTML::Form::Field>, then a fatal error occurs.
 
-The field object's C<name()> is set to the name that it is stored under, and
-its C<parent_field()> is set to the form object.
+The field object's L<name()|Rose::HTML::Form::Field/name> is set to the name that it is stored under, and its L<parent_field()|Rose::HTML::Form::Field/parent_field> is set to the form object.
 
-Returns the full list of field objects, sorted by field name, in list context,
-or a reference to a list of the same in scalar context.
+Returns the full list of field objects, sorted by field name, in list context, or a reference to a list of the same in scalar context.
 
 Examples:
 
@@ -852,24 +812,15 @@ Add VALUE to the parameter named NAME.  Example:
 
 =item B<build_on_init [BOOL]>
 
-Get or set a boolean flag that indicates whether or not C<build_form()> should
-be called from within the C<init()> method.  See C<build_form()> for more
-information.
+Get or set a boolean flag that indicates whether or not L<build_form()|/build_form> should be called from within the L<init()|Rose::Object/init> method.  See L<build_form()|/build_form> for more information.
 
 =item B<build_form>
 
-This method is a no-op in this class.  It is meant to be overridden by
-subclasses.  It is called at the end of the C<init()> method if
-C<build_on_init()> is true. (Remember that this class inherits from
-L<Rose::HTML::Object>, which inherits from L<Rose::Object>, which defines the
-C<init()> method, which is called from the constructor.  See the
-L<Rose::Object> documentation for more information.)
+This method is a no-op in this class.  It is meant to be overridden by subclasses.  It is called at the end of the L<init()|Rose::Object/init> method if L<build_on_init()|/build_on_init> is true. (Remember that this class inherits from L<Rose::HTML::Object>, which inherits from L<Rose::Object>, which defines the L<init()|Rose::Object/init> method, which is called from the constructor.  See the L<Rose::Object> documentation for more information.)
 
-If C<build_on_init()> is false, then you must remember to call C<build_form()>
-manually.
+If L<build_on_init()|/build_on_init> is false, then you must remember to call L<build_form()|/build_form> manually.
 
-Subclasses should populate the field list in their overridden versions of
-C<build_form()>.  Example:
+Subclasses should populate the field list in their overridden versions of L<build_form()|/build_form>.  Example:
 
   sub build_form 
   {
@@ -892,29 +843,25 @@ C<build_form()>.  Example:
     $self->add_fields(%fields);
   }
 
+=item B<clear>
+
+Call L<clear()|Rose::HTML::Form::Field/clear> on each field object and set L<error()|Rose::HTML::Object/error> to undef.
+
 =item B<clear_fields>
 
-Call C<clear()> on each field object.
+Call L<clear()|Rose::HTML::Form::Field/clear> on each field object.
 
 =item B<coalesce_hidden_fields [BOOL]>
 
-Get or set the boolean flag that controls how compound field values are
-encoded in hidden fields.  If this flag is true, then each compound field is
-encoded as a single hidden field.  If the flag is false (the default), then
-each subfield of a compound field will have its own hidden field.
+Get or set the boolean flag that controls how compound field values are encoded in hidden fields.  If this flag is true, then each compound field is encoded as a single hidden field.  If the flag is false (the default), then each subfield of a compound field will have its own hidden field.
 
 =item B<coalesce_query_string_params [BOOL]>
 
-Get or set the boolean flag that controls how compound field values are
-encoded in the query string. If this flag is true (the default), then compound
-fields are represented by a single query parameter. Otherwise, the subfields
-of each compound field appear as separate query parameters.
+Get or set the boolean flag that controls how compound field values are encoded in the query string. If this flag is true (the default), then compound fields are represented by a single query parameter. Otherwise, the subfields of each compound field appear as separate query parameters.
 
 =item B<delete_field NAME>
 
-Delete the field stored under the name NAME.  If NAME "isa"
-L<Rose::HTML::Form::Field>, then the C<name()> method is called on it and the
-return value is used as NAME.
+Delete the field stored under the name NAME.  If NAME "isa" L<Rose::HTML::Form::Field>, then the L<name()|Rose::HTML::Form::Field/name> method is called on it and the return value is used as NAME.
 
 =item B<delete_fields>
 
@@ -924,11 +871,7 @@ Delete all fields, leaving the list of fields empty.
 
 If just the NAME argument is passed, the parameter named NAME is deleted.
 
-If VALUES are also passed, then VALUES are deleted from the set of values held
-by the parameter name NAME.  If only one value remains, then it is the new
-value for the NAME parameter (i.e., the value is no longer an array reference,
-but a scalar instead).  If every value is deleted, then the NAME parameter is
-deleted as well.  Example:
+If VALUES are also passed, then VALUES are deleted from the set of values held by the parameter name NAME.  If only one value remains, then it is the new value for the NAME parameter (i.e., the value is no longer an array reference, but a scalar instead).  If every value is deleted, then the NAME parameter is deleted as well.  Example:
 
     $form->param(a => [ 1, 2, 3, 4 ]);
 
@@ -964,71 +907,43 @@ Returns the XHTML required to end a multipart form.
 
 =item B<field NAME [, VALUE]>
 
-Get or set the field specified by NAME.  If only a NAME argument is passed,
-then the field stored under the name NAME is returned.  If no field exists
-under that name exists, then undef is returned.
+Get or set the field specified by NAME.  If only a NAME argument is passed, then the field stored under the name NAME is returned.  If no field exists under that name exists, then undef is returned.
 
-If both NAME and VALUE arguments are passed, then the field VALUE is stored
-under the name NAME.  If VALUE is not an object derived from
-L<Rose::HTML::Form::Field>, then a fatal error occurs.
+If both NAME and VALUE arguments are passed, then the field VALUE is stored under the name NAME.  If VALUE is not an object derived from L<Rose::HTML::Form::Field>, then a fatal error occurs.
 
 =item B<fields>
 
-Returns the full list of field objects, sorted by field name, in list context,
-or a reference to a list of the same in scalar context.
+Returns the full list of field objects, sorted by field name, in list context, or a reference to a list of the same in scalar context.
 
 =item B<field_names>
 
-Returns a sorted list of field names in list context, or a reference to a list
-of the same in scalar context.
+Returns a sorted list of field names in list context, or a reference to a list of the same in scalar context.
 
 =item B<hidden_fields>
 
-Returns one or more L<Rose::HTML::Form::Field::Hidden> objects that represent
-the hidden fields needed to encode all of the field values in this form.
+Returns one or more L<Rose::HTML::Form::Field::Hidden> objects that represent the hidden fields needed to encode all of the field values in this form.
 
-If C<coalesce_hidden_fields()> is true, then each compound field is encoded as
-a single hidden field.  Otherwise, each subfield of a compound field will be
-have its own hidden field.
+If L<coalesce_hidden_fields()|/coalesce_hidden_fields> is true, then each compound field is encoded as a single hidden field.  Otherwise, each subfield of a compound field will be have its own hidden field.
 
 =item B<html_hidden_fields>
 
-Returns the HTML serialization of the fields returned by C<hidden_fields()>,
-joined by newlines.
+Returns the HTML serialization of the fields returned by L<hidden_fields()|/hidden_fields>, joined by newlines.
 
 =item B<init_fields [ARGS]>
 
-Initialize the fields based on C<params()>.  In general, this works as you'd
-expect, but the details are a bit complicated.
+Initialize the fields based on L<params()|/params>.  In general, this works as you'd expect, but the details are a bit complicated.
 
-The intention of C<init_fields()> is to set field values based solely and
-entirely on C<params()>.  That means that default values for fields should not
-be considered unless they are explicitly part of C<params()>.
+The intention of L<init_fields()|/init_fields> is to set field values based solely and entirely on L<params()|/params>.  That means that default values for fields should not be considered unless they are explicitly part of L<params()|/params>.
 
-In  general, default values for fields exist for the purpose of displaying the
-HTML form with certain items pre-selected or filled in.  In a typical usage
-scenario, those default values will end up in the web browser form submission
-and, eventually, as as an explicit part of part C<params()>, so they are not
-really ignored.
+In  general, default values for fields exist for the purpose of displaying the HTML form with certain items pre-selected or filled in.  In a typical usage scenario, those default values will end up in the web browser form submission and, eventually, as as an explicit part of part L<params()|/params>, so they are not really ignored.
 
-But to preserve the intended functionality of C<init_fields()>, the first thing
-this method does is C<clear()> the form. If a C<no_clear> parameter with a
-true value is passed as part of ARGS, then this step is skipped.
+But to preserve the intended functionality of L<init_fields()|/init_fields>, the first thing this method does is L<clear()|/clear> the form. If a C<no_clear> parameter with a true value is passed as part of ARGS, then this step is skipped.
 
-If a parameter name exactly matches a field's name (note: the field's
-C<name()>, I<not> the name that the field is stored under in the form, which
-may be different), then the (list context) value of that parameter is passed
-as the C<input_value()> for that field.
+If a parameter name exactly matches a field's name (note: the field's L<name()|Rose::HTML::Form::Field/name>, I<not> the name that the field is stored under in the form, which may be different), then the (list context) value of that parameter is passed as the L<input_value()|Rose::HTML::Form::Field/input_value> for that field.
 
-If a field "isa" L<Rose::HTML::Form::Field::Compound>, and if no parameter
-exactly matches the C<name()> of the compound field, then each subfields may
-be initialized by a parameter name that matches the subfield's C<name()>.
+If a field "isa" L<Rose::HTML::Form::Field::Compound>, and if no parameter exactly matches the L<name()|Rose::HTML::Form::Field/name> of the compound field, then each subfields may be initialized by a parameter name that matches the subfield's L<name()|Rose::HTML::Form::Field/name>.
 
-If a field is an "on/off" type of field (e.g., a radio button or checkbox),
-then the field is turned "on" only if the value of the parameter that matches
-the field's C<name()> exactly matches (string comparison) the "value" HTML
-attribute of the field.  If not, and if C<params_exist()>, then the field is
-set to "off".  Otherwise, the field is not modified at all.
+If a field is an "on/off" type of field (e.g., a radio button or checkbox), then the field is turned "on" only if the value of the parameter that matches the field's L<name()|Rose::HTML::Form::Field/name> exactly matches (string comparison) the "value" HTML attribute of the field.  If not, and if L<params_exist()|/params_exist>, then the field is set to "off".  Otherwise, the field is not modified at all.
 
 Examples:
 
@@ -1125,13 +1040,9 @@ Examples:
 
 =item B<init_with_object OBJECT>
 
-Initialize the form based on OBJECT.  First, the form is C<clear()>ed.  Next,
-for each field C<name()>, if the object has a method with the same name, then
-the return value of that method (called in scalar context) is passed as the
-C<input_value()> for the form field of the same name.
+Initialize the form based on OBJECT.  First, the form is L<clear()|/clear>ed.  Next, for each field L<name()|Rose::HTML::Form::Field/name>, if the object has a method with the same name, then the return value of that method (called in scalar context) is passed as the L<input_value()|Rose::HTML::Form::Field/input_value> for the form field of the same name.
 
-Heck, at this point, the actual code for the C<init_with_object()> method is
-shorter and more clear than my description.  Basically, it does this:
+Heck, at this point, the actual code for the L<init_with_object()|/init_with_object> method is shorter and more clear than my description.  Basically, it does this:
 
     sub init_with_object
     {
@@ -1150,20 +1061,11 @@ shorter and more clear than my description.  Basically, it does this:
       }
     }
 
-Use this method as a "helper" when writing your own methods such as
-C<init_with_person()>, as described in the example in the L<OVERVIEW>.
-C<init_with_object()> should be called in the code for subclasses of
-L<Rose::HTML::Form>, but never by an end-user of such classes.
+Use this method as a "helper" when writing your own methods such as C<init_with_person()>, as described in the example in the L<OVERVIEW>. L<init_with_object()|/init_with_object> should be called in the code for subclasses of L<Rose::HTML::Form>, but never by an end-user of such classes.
 
-The convention for naming such methods is "init_with_foo", where "foo" is a
-(lowercase, underscore-separated, please) description of the object (or
-objects) used to initialize the form.  You are free to accept and handle 
-any kind or number of arguments in your "init_with_foo()"-style methods
-(all which you'll carefully document, of course).
+The convention for naming such methods is "init_with_foo", where "foo" is a (lowercase, underscore-separated, please) description of the object (or objects) used to initialize the form.  You are free to accept and handle any kind or number of arguments in your "init_with_foo()"-style methods (all which you'll carefully document, of course).
 
-The field names may not match up exactly with the object method names. In such
-cases, you can use C<init_with_object()> to handle all the fields that do
-match up with method names, and then handle the others manually.  Example:
+The field names may not match up exactly with the object method names. In such cases, you can use L<init_with_object()|/init_with_object> to handle all the fields that do match up with method names, and then handle the others manually.  Example:
 
     sub init_with_person 
     {
@@ -1182,9 +1084,7 @@ match up with method names, and then handle the others manually.  Example:
 
 Returns an object built based on the contents of the form.  
 
-For each field C<name()>, if the object has a method with the same name, then
-the C<internal_value()> of the field is passed to the object method of that
-name.  The actual code is just about as concise as my description:
+For each field L<name()|Rose::HTML::Form::Field/name>, if the object has a method with the same name, then the L<internal_value()|Rose::HTML::Form::Field/internal_value> of the field is passed to the object method of that name.  The actual code is just about as concise as my description:
 
   foreach my $field ($self->fields)
   {
@@ -1196,23 +1096,13 @@ name.  The actual code is just about as concise as my description:
     }
   }
 
-To do this, the method needs an object.  If passed an OBJECT argument, then
-that's the object that's used.  If passed a CLASS name, then a new object is
-constructed by calling C<new()> on that class.  OBJECT or CLASS may
-alternately be passed as a name/value pair in PARAMS.
+To do this, the method needs an object.  If passed an OBJECT argument, then that's the object that's used.  If passed a CLASS name, then a new object is constructed by calling L<new()|/new> on that class.  OBJECT or CLASS may alternately be passed as a name/value pair in PARAMS.
 
-Use this method as a "helper" when writing your own methods such as
-C<person_from_form()>, as described in the example in the L<OVERVIEW>.
-C<object_from_form()> should be called in the code for subclasses of
-L<Rose::HTML::Form>, but never by an end-user of such classes.
+Use this method as a "helper" when writing your own methods such as C<person_from_form()>, as described in the example in the L<OVERVIEW>. L<object_from_form()|/object_from_form> should be called in the code for subclasses of L<Rose::HTML::Form>, but never by an end-user of such classes.
 
-The convention for naming such methods is "foo_from_form", where "foo" is a
-(lowercase, underscore-separated, please) description of the object
-constructed based on the values in the form's fields.
+The convention for naming such methods is "foo_from_form", where "foo" is a (lowercase, underscore-separated, please) description of the object constructed based on the values in the form's fields.
 
-The field names may not match up exactly with the object method names. In such
-cases, you can use C<object_from_form()> to handle all the fields that do
-match up with method names, and then handle the others manually.  Example:
+The field names may not match up exactly with the object method names. In such cases, you can use L<object_from_form()|/object_from_form> to handle all the fields that do match up with method names, and then handle the others manually.  Example:
 
   sub person_from_form
   {
@@ -1225,18 +1115,13 @@ match up with method names, and then handle the others manually.  Example:
     return $person;
   }
 
-It is the caller's responsibility to ensure that the object class (C<Person>
-in the example above) is loaded prior to calling this method.
+It is the caller's responsibility to ensure that the object class (C<Person> in the example above) is loaded prior to calling this method.
 
 =item B<param NAME [, VALUE]>
 
-Get or set the value of a named parameter.  If just NAME is passed, then the
-value of the parameter of that name is returned.  If VALUE is also passed,
-then the parameter value is set and then returned.
+Get or set the value of a named parameter.  If just NAME is passed, then the value of the parameter of that name is returned.  If VALUE is also passed, then the parameter value is set and then returned.
 
-If a parameter has multiple values, the values are returned as a reference to
-an array in scalar context, or as a list in list context.  Multiple values are
-set by passing a VALUE that is a reference to an array of scalars.
+If a parameter has multiple values, the values are returned as a reference to an array in scalar context, or as a list in list context.  Multiple values are set by passing a VALUE that is a reference to an array of scalars.
 
 Failure to pass at least a NAME argument results in a fatal error.
 
@@ -1244,25 +1129,15 @@ Failure to pass at least a NAME argument results in a fatal error.
 
 Get or set all parameters at once.
 
-PARAMS can be a reference to a hash or a list of name/value pairs.  If a
-parameter has multiple values, those values should be provided in the form of
-a references to an array of scalar values.  If the list of name/value pairs
-has an odd number of items, a fatal error occurs.
+PARAMS can be a reference to a hash or a list of name/value pairs.  If a parameter has multiple values, those values should be provided in the form of a references to an array of scalar values.  If the list of name/value pairs has an odd number of items, a fatal error occurs.
 
-Regardless of the arguments, this method returns the complete set of
-parameters in the form of a hash (in list context) or a reference to a hash
-(in scalar context).
+Regardless of the arguments, this method returns the complete set of parameters in the form of a hash (in list context) or a reference to a hash (in scalar context).
 
-In scalar context, the hash reference returned is a reference to the actual
-hash used to store parameter names and values in the object.  It should
-be treated as read-only.
+In scalar context, the hash reference returned is a reference to the actual hash used to store parameter names and values in the object.  It should be treated as read-only.
 
-The hash returned in list context is a shallow copy of the actual hash used to
-store parameter names and values in the object.  It should also be treated as
-read-only.
+The hash returned in list context is a shallow copy of the actual hash used to store parameter names and values in the object.  It should also be treated as read-only.
 
-If you want a read/write copy, make a deep copy of the hash reference return
-value and then modify the copy.
+If you want a read/write copy, make a deep copy of the hash reference return value and then modify the copy.
 
 =item B<params_exist>
 
@@ -1274,34 +1149,25 @@ Returns true if a parameter named NAME exists, false otherwise.
 
 =item B<param_value_exists NAME, VALUE>
 
-Determines if a parameter of a particular name exists and has a particular
-value. This method returns true if the parameter named NAME exists and also
-has a value that is equal to (string comparison) VALUE. Otherwise, it returns
-false.
+Determines if a parameter of a particular name exists and has a particular value. This method returns true if the parameter named NAME exists and also has a value that is equal to (string comparison) VALUE. Otherwise, it returns false.
 
 A fatal error occurs unless both NAME and VALUE arguments are passed.
 
 =item B<query_string>
 
-Returns a URI-escaped (but I<not> HTML-escaped) query string that corresponds
-to the current state of the form.  If C<coalesce_query_string_params()> is
-true (which is the default), then compound fields are represented by a single
-query parameter.  Otherwise, the subfields of each compound field appear as
-separate query parameters.
+Returns a URI-escaped (but I<not> HTML-escaped) query string that corresponds to the current state of the form.  If L<coalesce_query_string_params()|/coalesce_query_string_params> is true (which is the default), then compound fields are represented by a single query parameter.  Otherwise, the subfields of each compound field appear as separate query parameters.
 
 =item B<reset>
 
-Call C<reset()> on each field object and set C<error()> to undef.
+Call L<reset()|Rose::HTML::Form::Field/reset> on each field object and set L<error()|Rose::HTML::Object/error> to undef.
 
 =item B<reset_fields>
 
-Call C<reset()> on each field object.
+Call L<reset()|/reset> on each field object.
 
 =item B<self_uri>
 
-Returns a L<Rose::URI> object corresponding to the current state of the form.
-If C<uri_base()> is set, then it is included in front of what would otherwise
-be the start of the URI (i.e., the value of the form's "action" HTML attribute).
+Returns a L<Rose::URI> object corresponding to the current state of the form. If L<uri_base()|/uri_base> is set, then it is included in front of what would otherwise be the start of the URI (i.e., the value of the form's "action" HTML attribute).
 
 =item B<start_html>
 
@@ -1313,20 +1179,15 @@ Returns the XHTML that will begin the form tag.
 
 =item B<start_multipart_html>
 
-Sets the "enctype" HTML attribute to "multipart/form-data", then returns the
-HTML that will begin the form tag.
+Sets the "enctype" HTML attribute to "multipart/form-data", then returns the HTML that will begin the form tag.
 
 =item B<start_multipart_xhtml>
 
-Sets the "enctype" HTML attribute to "multipart/form-data", then returns the
-XHTML that will begin the form tag.
+Sets the "enctype" HTML attribute to "multipart/form-data", then returns the XHTML that will begin the form tag.
 
 =item B<uri_base [STRING]>
 
-Get or set the URI of the form, minus the value of the "action" HTML
-attribute.  Although the form action can be a relative URI, I suggest that it
-be an absolute path at the very least, leaving the C<uri_base()> to be the
-initial part of the full URI returned by C<self_uri()>.  Example:
+Get or set the URI of the form, minus the value of the "action" HTML attribute.  Although the form action can be a relative URI, I suggest that it be an absolute path at the very least, leaving the L<uri_base()|/uri_base> to be the initial part of the full URI returned by L<self_uri()|/self_uri>.  Example:
 
     $form->action('/foo/bar');
     $form->uri_base('http://www.foo.com');
@@ -1336,36 +1197,36 @@ initial part of the full URI returned by C<self_uri()>.  Example:
 
 =item B<uri_separator [CHAR]>
 
-Get or set the character used to separate parameter name/value pairs in the
-return value of C<query_string()> (which is in turn used to construct
-the return value of C<self_uri()>).  The default is "&".
+Get or set the character used to separate parameter name/value pairs in the return value of L<query_string()|/query_string> (which is in turn used to construct the return value of L<self_uri()|/self_uri>).  The default is "&".
 
 =item B<validate>
 
-Validate the form by calling C<validate()> on each field.  If any field
-returns false from its C<validate()> call, then this method returns false. 
-Otherwise, it returns true.
+Validate the form by calling L<validate()|Rose::HTML::Form::Field/validate> on each field.  If any field returns false from its L<validate()|Rose::HTML::Form::Field/validate> call, then this method returns false. Otherwise, it returns true.
 
 =item B<validate_field_html_attrs [BOOL]>
 
-Get or set a boolean flag that indicates whether or not the fields of this
-form will validate their HTML attributes.  If a BOOL argument is passed, then
-it is passed as the argument to a call to C<validate_html_attrs()> on each
-field.  In either case, the current value of this flag is returned.
+Get or set a boolean flag that indicates whether or not the fields of this form will validate their HTML attributes.  If a BOOL argument is passed, then it is passed as the argument to a call to L<validate_html_attrs()|Rose::HTML::Object/validate_html_attrs> on each field.  In either case, the current value of this flag is returned.
 
 =item B<xhtml_hidden_fields>
 
-Returns the XHTML serialization of the fields returned by C<hidden_fields()>,
-joined by newlines.
+Returns the XHTML serialization of the fields returned by L<hidden_fields()|/hidden_fields>, joined by newlines.
 
 =back
 
+=head1 SUPPORT
+
+Any L<Rose::HTML::Objects> questions or problems can be posted to the L<Rose::HTML::Objects> mailing list.  To subscribe to the list or view the archives, go here:
+
+L<http://lists.sourceforge.net/lists/listinfo/rose-html-objects>
+
+Although the mailing list is the preferred support mechanism, you can also email the author (see below) or file bugs using the CPAN bug tracking system:
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Rose-HTML-Objects>
+
 =head1 AUTHOR
 
 John C. Siracusa (siracusa@mindspring.com)
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005 by John C. Siracusa.  All rights reserved.  This program is
-free software; you can redistribute it and/or modify it under the same terms
-as Perl itself.
+Copyright (c) 2005 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
